"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConstructableSPIInterface = exports.SPIMasterInterface = exports.SPISlaveInterface = exports.Polarity = exports.Phase = void 0;
const tiny_typed_emitter_1 = require("tiny-typed-emitter");
const InterfaceType = "spi";
const InterfaceTypeSlave = "spiSlave";
const InterfaceTypeMaster = "spiMaster";
var Phase;
(function (Phase) {
    Phase[Phase["SampleLeadingEdge"] = 0] = "SampleLeadingEdge";
    Phase[Phase["SetupLeadingEdge"] = 1] = "SetupLeadingEdge";
})(Phase = exports.Phase || (exports.Phase = {}));
var Polarity;
(function (Polarity) {
    Polarity[Polarity["LeadingRisingEdge"] = 0] = "LeadingRisingEdge";
    Polarity[Polarity["LeadingFallingEdge"] = 1] = "LeadingFallingEdge";
})(Polarity = exports.Polarity || (exports.Polarity = {}));
class SPISlaveInterface extends tiny_typed_emitter_1.TypedEmitter {
    constructor(configuration) {
        super();
        this.interfaceType = InterfaceTypeSlave;
        this.configuration = configuration;
    }
    retransmit() {
        throw new Error("Method not implemented.");
    }
    // TODO: add real implementation
    downstreamData(data) {
        console.log(data);
    }
    sendByte(byte) {
        const data = { type: "SendByte", byte: byte };
        this.emit("upstreamData", data);
        this.downstreamData(data);
    }
    setSlaveSelect(value) {
        const data = { type: "SetSlaveSelect", value: value };
        this.emit("upstreamData", data);
        this.downstreamData(data);
    }
}
exports.SPISlaveInterface = SPISlaveInterface;
class SPIMasterInterface extends tiny_typed_emitter_1.TypedEmitter {
    constructor(configuration) {
        super();
        this.interfaceType = InterfaceTypeMaster;
        this.configuration = configuration;
    }
    retransmit() {
        throw new Error("Method not implemented.");
    }
    // TODO: add real implementation
    downstreamData(data) {
        console.log(data);
    }
    prepareByte(byte) {
        const data = { type: "PrepareByte", byte: byte };
        this.emit("upstreamData", data);
        this.downstreamData(data);
    }
}
exports.SPIMasterInterface = SPIMasterInterface;
class ConstructableSPIInterface {
    constructor(signals) {
        this.interfaceType = InterfaceType;
        this.signals = signals;
    }
    getDescription() {
        return {
            availableSignals: { spi: this.signals },
        };
    }
    create(configuration) {
        if (configuration.representsAMaster) {
            return new SPIMasterInterface(configuration);
        }
        else {
            return new SPISlaveInterface(configuration);
        }
    }
}
exports.ConstructableSPIInterface = ConstructableSPIInterface;
//# sourceMappingURL=connectionInterface.js.map