import { TypedEmitter } from 'tiny-typed-emitter';
import { ConnectionInterface, ConnectionInterfaceConfiguration, ConnectionInterfaceDescription, ConnectionInterfaceEvents, ConstructableConnectionInterface } from '../connectionInterface';
type InterfaceType = 'gpio';
declare const InterfaceType: InterfaceType;
export interface GPIOConfiguration extends ConnectionInterfaceConfiguration {
    signals: {
        gpio: string;
    };
    driver: string;
    direction?: 'in' | 'out' | 'inout';
}
export declare enum GPIOState {
    'Unknown' = "unknown",
    'Error' = "error",
    'StrongLow' = "strongL",
    'StrongHigh' = "strongH",
    'HighZ' = "highZ",
    'WeakLow' = "weakL",
    'WeakHigh' = "weakH"
}
interface GPIOInterfaceData {
    driver: string;
    state: GPIOState;
}
type SignalChangeEvent = {
    state: GPIOState;
    oldState: GPIOState;
};
export interface GPIOInterfaceEvents extends ConnectionInterfaceEvents {
    signalChange(event: SignalChangeEvent): void;
}
export declare class GPIOInterface extends TypedEmitter<GPIOInterfaceEvents> implements ConnectionInterface {
    interfaceType: "gpio";
    readonly configuration: GPIOConfiguration;
    signalState: GPIOState;
    private driverStates;
    private driverState;
    private driver?;
    constructor(configuration: GPIOConfiguration);
    changeDriver(state: GPIOState): void;
    retransmit(): void;
    downstreamData(data: GPIOInterfaceData): void;
    private evaluateSignalState;
}
export declare class ConstructableGPIOInterface implements ConstructableConnectionInterface {
    interfaceType: InterfaceType;
    private gpios;
    constructor(gpios: string[]);
    getDescription(): ConnectionInterfaceDescription;
    create(configuration: GPIOConfiguration): GPIOInterface;
}
export {};
//# sourceMappingURL=connectionInterface.d.ts.map